==> eiffelstudio-23.09.10.7341.tar: F_code/C3/sy139.c <==
/*
 * Code for class SYSTEM_ENCODINGS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sy139.h"
#include "eif_langinfo.h"
#include <locale.h>
#include "eif_built_in.h"
#include "string.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F151_3031
static EIF_POINTER inline_F151_3031 (void)
{
	return nl_langinfo (CODESET);
	;
}
#define INLINE_F151_3031
#endif
#ifndef INLINE_F151_3030
static int inline_F151_3030 (void)
{
	setlocale (LC_ALL, "");
return (EIF_BOOLEAN)(strcmp (nl_langinfo (CODESET), "UTF-8") == 0);
	;
}
#define INLINE_F151_3030
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SYSTEM_ENCODINGS_IMP}.system_code_page */
EIF_REFERENCE F151_3027 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	loc1 = inline_F151_3031();
	ti4_1 = (EIF_INTEGER_32) strlen((void *) loc1);
	Result = F150_3017(Current, loc1, ti4_1);
	RTLE;
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.console_code_page */
EIF_REFERENCE F151_3028 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	if (EIF_TEST (inline_F151_3030())) {
		Result = RTMS_EX_H("UTF-8",5,1414538040);
	} else {
		if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows__b) {
			Result = RTMS_EX_H("UTF-8",5,1414538040);
		} else {
			Result = F151_3027(Current);
			RTLE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTLE;
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.is_utf8_activated */
EIF_BOOLEAN F151_3030 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = EIF_TEST(inline_F151_3030 ());
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.c_current_codeset */
EIF_POINTER F151_3031 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	
	Result = inline_F151_3031 ();
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.c_strlen */
EIF_INTEGER_32 F151_3032 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	
	Result = (EIF_INTEGER_32) strlen((void *) arg1);
	
	return Result;
}

void EIF_Minit139 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C3/sy139.c <==
/*
 * Code for class SYSTEM_ENCODINGS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sy139.h"
#include "string.h"
#include "eif_built_in.h"
#include "eif_langinfo.h"
#include <locale.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F185_2497
static EIF_POINTER inline_F185_2497 (void)
{
	return nl_langinfo (CODESET);
	;
}
#define INLINE_F185_2497
#endif
#ifndef INLINE_F185_2496
static int inline_F185_2496 (void)
{
	setlocale (LC_ALL, "");
return (EIF_BOOLEAN)(strcmp (nl_langinfo (CODESET), "UTF-8") == 0);
	;
}
#define INLINE_F185_2496
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SYSTEM_ENCODINGS_IMP}.system_code_page */
EIF_REFERENCE F185_2493 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	loc1 = inline_F185_2497();
	ti4_1 = (EIF_INTEGER_32) strlen((void *) loc1);
	Result = F184_2483(Current, loc1, ti4_1);
	RTLE;
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.console_code_page */
EIF_REFERENCE F185_2494 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	if (EIF_TEST (inline_F185_2496())) {
		Result = RTMS_EX_H("UTF-8",5,1414538040);
	} else {
		if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows__b) {
			Result = RTMS_EX_H("UTF-8",5,1414538040);
		} else {
			Result = F185_2493(Current);
			RTLE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTLE;
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.iso_8859_1_code_page */
EIF_REFERENCE F185_2495 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	RTGC;
	Result = RTMS_EX_H("ISO-8859-1",10,1255164721);
	RTLE;
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.is_utf8_activated */
EIF_BOOLEAN F185_2496 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = EIF_TEST(inline_F185_2496 ());
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.c_current_codeset */
EIF_POINTER F185_2497 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	
	Result = inline_F185_2497 ();
	return Result;
}

/* {SYSTEM_ENCODINGS_IMP}.c_strlen */
EIF_INTEGER_32 F185_2498 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	
	Result = (EIF_INTEGER_32) strlen((void *) arg1);
	
	return Result;
}

void EIF_Minit139 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
